SystemOrganization addCategory: #ConfigurationOfGTInspectorCore!

Object subclass: #ConfigurationOfGTInspectorCore
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfGTInspectorCore'!

!ConfigurationOfGTInspectorCore commentStamp: 'AndreiChis 10/29/2014 11:37' prior: 0!
Core configuration of the GTInspector for integrating with Pharo.

self loadDevelopment!

!ConfigurationOfGTInspectorCore class methodsFor: 'development support' stamp: 'AndreiChis 10/29/2014 11:14'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfGTInspectorCore class methodsFor: 'private' stamp: 'AndreiChis 10/29/2014 11:14'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfGTInspectorCore class methodsFor: 'private' stamp: 'AndreiChis 10/29/2014 11:14'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfGTInspectorCore class methodsFor: 'private' stamp: 'AndreiChis 10/29/2014 11:14'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfGTInspectorCore class methodsFor: 'metacello tool support' stamp: 'AndreiChis 10/29/2014 11:14'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfGTInspectorCore class methodsFor: 'loading' stamp: 'AndreiChis 10/29/2014 11:14'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfGTInspectorCore class methodsFor: 'loading' stamp: 'AndreiChis 10/29/2014 11:14'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfGTInspectorCore class methodsFor: 'loading' stamp: 'AndreiChis 10/29/2014 11:14'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfGTInspectorCore class methodsFor: 'accessing' stamp: 'AndreiChis 10/29/2014 11:14'!
project

	^self new project! !

!ConfigurationOfGTInspectorCore class methodsFor: 'development support' stamp: 'AndreiChis 10/29/2014 11:14'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfGTInspectorCore methodsFor: 'baselines' stamp: 'AndreiChis 10/29/2014 12:00'!
baseline20: spec
	<version: '2.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: 'GTInspector Core'.
		spec author: 'AndreiChis'.
		spec timestamp: '2014-10-29'.
		spec repository: 'http://smalltalkhub.com/mc/Moose/GToolkit/main/'.
		
		spec 
			package: 'GT-Inspector' with: [
				spec requires: #('GlamourCore' ). ];
			package: 'GT-InspectorExtensions-Core' with: [
				spec requires: #('GT-Inspector' 'GlamourCore' ). ];
			package: 'GT-Tests-Inspector' with: [
				spec requires: #('GT-Inspector' 'GT-InspectorExtensions-Core' ). ].
		
		spec 
			project: 'GlamourCore' with: [
				spec
					className: #ConfigurationOfGlamourCore;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/Moose/Glamour/main/' ].
		
		spec 
			group: 'Core' with: #('GT-Inspector' 'GT-InspectorExtensions-Core' );
			group: 'Tests' with: #('GT-Tests-Inspector' );
			group: 'default' with: #('GT-Inspector' 'GT-InspectorExtensions-Core' 'GT-Tests-Inspector' ) ]
! !

!ConfigurationOfGTInspectorCore methodsFor: 'accessing' stamp: 'AndreiChis 10/29/2014 11:14'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfGTInspectorCore methodsFor: 'symbolic versions' stamp: 'AndreiChis 10/29/2014 12:00'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '2.0-baseline'.
! !

!ConfigurationOfGTInspectorCore methodsFor: 'accessing' stamp: 'AndreiChis 10/29/2014 11:14'!
project

	^ project ifNil: [ 
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !
